@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *     https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -52,7 +52,7 @@ import org.apache.commons.text.StringSubstitutor;
  * for it. Then the name of the variable is passed to this object to obtain the actual value. It is also possible to
  * define an arbitrary number of default lookup objects, which are used for variables that do not have a prefix or that
  * cannot be resolved by their associated lookup object. When adding default lookup objects their order matters; they
- * are queried in this order, and the first non-<b>null</b> variable value is used.
+ * are queried in this order, and the first non-<strong>null</strong> variable value is used.
  * </p>
  * <p>
  * After an instance has been created it does not contain any {@code Lookup} objects. The current set of lookup objects
@@ -78,7 +78,7 @@ import org.apache.commons.text.StringSubstitutor;
  * {@link org.apache.commons.configuration2.convert.DefaultConversionHandler DefaultConversionHandler}, when a variable
  * value is a container type (such as a collection or array), then only the first element of the container is converted
  * to a string instead of the container itself. For example, if the variable {@code x} resolves to the integer array
- * {@code [1, 2, 3]}, then the string <code>"my value = ${x}"</code> will by default be interpolated to
+ * {@code [1, 2, 3]}, then the string {@code "my value = ${x}"} will by default be interpolated to
  * {@code "my value = 1"}.
  * </p>
  * <p>
@@ -90,6 +90,146 @@ import org.apache.commons.text.StringSubstitutor;
  */
 public class ConfigurationInterpolator {
 
+    /**
+     * Internal class used to construct the default {@link Lookup} map used by
+     * {@link ConfigurationInterpolator#getDefaultPrefixLookups()}.
+     */
+    static final class DefaultPrefixLookupsHolder {
+
+        /** Singleton instance, initialized with the system properties. */
+        static final DefaultPrefixLookupsHolder INSTANCE = new DefaultPrefixLookupsHolder(System.getProperties());
+
+        /**
+         * Add the prefix and lookup from {@code lookup} to {@code map}.
+         * @param lookup lookup to add
+         * @param map map to add to
+         */
+        private static void addLookup(final DefaultLookups lookup, final Map<String, Lookup> map) {
+            map.put(lookup.getPrefix(), lookup.getLookup());
+        }
+
+        /**
+         * Create the lookup map used when the user has requested no customization.
+         * @return default lookup map
+         */
+        private static Map<String, Lookup> createDefaultLookups() {
+            final Map<String, Lookup> lookupMap = new HashMap<>();
+
+            addLookup(DefaultLookups.BASE64_DECODER, lookupMap);
+            addLookup(DefaultLookups.BASE64_ENCODER, lookupMap);
+            addLookup(DefaultLookups.CONST, lookupMap);
+            addLookup(DefaultLookups.DATE, lookupMap);
+            addLookup(DefaultLookups.ENVIRONMENT, lookupMap);
+            addLookup(DefaultLookups.FILE, lookupMap);
+            addLookup(DefaultLookups.JAVA, lookupMap);
+            addLookup(DefaultLookups.LOCAL_HOST, lookupMap);
+            addLookup(DefaultLookups.PROPERTIES, lookupMap);
+            addLookup(DefaultLookups.RESOURCE_BUNDLE, lookupMap);
+            addLookup(DefaultLookups.SYSTEM_PROPERTIES, lookupMap);
+            addLookup(DefaultLookups.URL_DECODER, lookupMap);
+            addLookup(DefaultLookups.URL_ENCODER, lookupMap);
+            addLookup(DefaultLookups.XML, lookupMap);
+
+            return lookupMap;
+        }
+
+        /**
+         * Constructs a lookup map by parsing the given string. The string is expected to contain
+         * comma or space-separated names of values from the {@link DefaultLookups} enum.
+         * @param str string to parse; not null
+         * @return lookup map parsed from the given string
+         * @throws IllegalArgumentException if the string does not contain a valid default lookup
+         *      definition
+         */
+        private static Map<String, Lookup> parseLookups(final String str) {
+            final Map<String, Lookup> lookupMap = new HashMap<>();
+
+            try {
+                for (final String lookupName : str.split("[\\s,]+")) {
+                    if (!lookupName.isEmpty()) {
+                        addLookup(DefaultLookups.valueOf(lookupName.toUpperCase()), lookupMap);
+                    }
+                }
+            } catch (final IllegalArgumentException exc) {
+                throw new IllegalArgumentException("Invalid default lookups definition: " + str, exc);
+            }
+
+            return lookupMap;
+        }
+
+        /** Default lookup map. */
+        private final Map<String, Lookup> defaultLookups;
+
+        /**
+         * Constructs a new instance initialized with the given properties.
+         * @param props initialization properties
+         */
+        DefaultPrefixLookupsHolder(final Properties props) {
+            final Map<String, Lookup> lookups = props.containsKey(DEFAULT_PREFIX_LOOKUPS_PROPERTY)
+                        ? parseLookups(props.getProperty(DEFAULT_PREFIX_LOOKUPS_PROPERTY))
+                        : createDefaultLookups();
+
+            defaultLookups = Collections.unmodifiableMap(lookups);
+        }
+
+        /**
+         * Gets the default prefix lookups map.
+         * @return default prefix lookups map
+         */
+        Map<String, Lookup> getDefaultPrefixLookups() {
+            return defaultLookups;
+        }
+    }
+
+    /** Class encapsulating the default logic to convert resolved variable values into strings.
+     * This class is thread-safe.
+     */
+    private static final class DefaultStringConverter implements Function<Object, String> {
+
+        /** Shared instance. */
+        static final DefaultStringConverter INSTANCE = new DefaultStringConverter();
+
+        /** {@inheritDoc} */
+        @Override
+        public String apply(final Object obj) {
+            return Objects.toString(extractSimpleValue(obj), null);
+        }
+
+        /** Attempt to extract a simple value from {@code obj} for use in string conversion.
+         * If the input represents a collection of some sort (for example, an iterable or array),
+         * the first item from the collection is returned.
+         * @param obj input object
+         * @return extracted simple object
+         */
+        private Object extractSimpleValue(final Object obj) {
+            if (!(obj instanceof String)) {
+                if (obj instanceof Iterable) {
+                   return nextOrNull(((Iterable<?>) obj).iterator());
+                }
+                if (obj instanceof Iterator) {
+                    return nextOrNull((Iterator<?>) obj);
+                }
+                if (obj.getClass().isArray()) {
+                    return Array.getLength(obj) > 0
+                            ? Array.get(obj, 0)
+                            : null;
+                }
+            }
+            return obj;
+        }
+
+        /** Return the next value from {@code it} or {@code null} if no values remain.
+         * @param <T> iterated type
+         * @param it iterator
+         * @return next value from {@code it} or {@code null} if no values remain
+         */
+        private <T> T nextOrNull(final Iterator<T> it) {
+            return it.hasNext()
+                    ? it.next()
+                    : null;
+        }
+    }
+
     /**
      * Name of the system property used to determine the lookups added by the
      * {@link #getDefaultPrefixLookups()} method. Use of this property is only required
@@ -115,30 +255,6 @@ public class ConfigurationInterpolator {
     /** The length of {@link #VAR_END}. */
     private static final int VAR_END_LENGTH = VAR_END.length();
 
-    /** A map with the currently registered lookup objects. */
-    private final Map<String, Lookup> prefixLookups;
-
-    /** Stores the default lookup objects. */
-    private final List<Lookup> defaultLookups;
-
-    /** The helper object performing variable substitution. */
-    private final StringSubstitutor substitutor;
-
-    /** Stores a parent interpolator objects if the interpolator is nested hierarchically. */
-    private volatile ConfigurationInterpolator parentInterpolator;
-
-    /** Function used to convert interpolated values to strings. */
-    private volatile Function<Object, String> stringConverter = DefaultStringConverter.INSTANCE;
-
-    /**
-     * Creates a new instance of {@code ConfigurationInterpolator}.
-     */
-    public ConfigurationInterpolator() {
-        prefixLookups = new ConcurrentHashMap<>();
-        defaultLookups = new CopyOnWriteArrayList<>();
-        substitutor = initSubstitutor();
-    }
-
     /**
      * Creates a new instance based on the properties in the given specification object.
      *
@@ -169,9 +285,9 @@ public class ConfigurationInterpolator {
      * {@code InterpolatorSpecification} already contains a {@code ConfigurationInterpolator} object, it is used directly.
      * Otherwise, a new instance is created and initialized with the properties stored in the specification.
      *
-     * @param spec the {@code InterpolatorSpecification} (must not be <b>null</b>)
+     * @param spec the {@code InterpolatorSpecification} (must not be <strong>null</strong>)
      * @return the {@code ConfigurationInterpolator} obtained or created based on the given specification
-     * @throws IllegalArgumentException if the specification is <b>null</b>
+     * @throws IllegalArgumentException if the specification is <strong>null</strong>
      * @since 2.0
      */
     public static ConfigurationInterpolator fromSpecification(final InterpolatorSpecification spec) {
@@ -188,8 +304,8 @@ public class ConfigurationInterpolator {
      *
      * <p>
      * All of the lookups present in the returned map are from {@link DefaultLookups}. However, not all of the
-     * available lookups are included by default. Specifically, lookups that can execute code (e.g.,
-     * {@link DefaultLookups#SCRIPT SCRIPT}) and those that can result in contact with remote servers (e.g.,
+     * available lookups are included by default. Specifically, lookups that can execute code (for example,
+     * {@link DefaultLookups#SCRIPT SCRIPT}) and those that can result in contact with remote servers (for example,
      * {@link DefaultLookups#URL URL} and {@link DefaultLookups#DNS DNS}) are not included. If this behavior
      * must be modified, users can define the {@value #DEFAULT_PREFIX_LOOKUPS_PROPERTY} system property
      * with a comma-separated list of {@link DefaultLookups} enum names to be included in the set of defaults.
@@ -291,12 +407,12 @@ public class ConfigurationInterpolator {
     }
 
     /**
-     * Utility method for obtaining a {@code Lookup} object in a safe way. This method always returns a non-<b>null</b>
-     * {@code Lookup} object. If the passed in {@code Lookup} is not <b>null</b>, it is directly returned. Otherwise, result
+     * Utility method for obtaining a {@code Lookup} object in a safe way. This method always returns a non-<strong>null</strong>
+     * {@code Lookup} object. If the passed in {@code Lookup} is not <strong>null</strong>, it is directly returned. Otherwise, result
      * is a dummy {@code Lookup} which does not provide any values.
      *
      * @param lookup the {@code Lookup} to check
-     * @return a non-<b>null</b> {@code Lookup} object
+     * @return a non-<strong>null</strong> {@code Lookup} object
      * @since 2.0
      */
     public static Lookup nullSafeLookup(Lookup lookup) {
@@ -306,24 +422,48 @@ public class ConfigurationInterpolator {
         return lookup;
     }
 
+    /** A map with the currently registered lookup objects. */
+    private final Map<String, Lookup> prefixLookups;
+
+    /** Stores the default lookup objects. */
+    private final List<Lookup> defaultLookups;
+
+    /** The helper object performing variable substitution. */
+    private final StringSubstitutor substitutor;
+
+    /** Stores a parent interpolator objects if the interpolator is nested hierarchically. */
+    private volatile ConfigurationInterpolator parentInterpolator;
+
+    /** Function used to convert interpolated values to strings. */
+    private volatile Function<Object, String> stringConverter = DefaultStringConverter.INSTANCE;
+
+    /**
+     * Creates a new instance of {@code ConfigurationInterpolator}.
+     */
+    public ConfigurationInterpolator() {
+        prefixLookups = new ConcurrentHashMap<>();
+        defaultLookups = new CopyOnWriteArrayList<>();
+        substitutor = initSubstitutor();
+    }
+
     /**
      * Adds a default {@code Lookup} object. Default {@code Lookup} objects are queried (in the order they were added) for
      * all variables without a special prefix. If no default {@code Lookup} objects are present, such variables won't be
      * processed.
      *
-     * @param defaultLookup the default {@code Lookup} object to be added (must not be <b>null</b>)
-     * @throws IllegalArgumentException if the {@code Lookup} object is <b>null</b>
+     * @param defaultLookup the default {@code Lookup} object to be added (must not be <strong>null</strong>)
+     * @throws IllegalArgumentException if the {@code Lookup} object is <strong>null</strong>
      */
     public void addDefaultLookup(final Lookup defaultLookup) {
         defaultLookups.add(defaultLookup);
     }
 
     /**
-     * Adds all {@code Lookup} objects in the given collection as default lookups. The collection can be <b>null</b>, then
-     * this method has no effect. It must not contain <b>null</b> entries.
+     * Adds all {@code Lookup} objects in the given collection as default lookups. The collection can be <strong>null</strong>, then
+     * this method has no effect. It must not contain <strong>null</strong> entries.
      *
      * @param lookups the {@code Lookup} objects to be added as default lookups
-     * @throws IllegalArgumentException if the collection contains a <b>null</b> entry
+     * @throws IllegalArgumentException if the collection contains a <strong>null</strong> entry
      */
     public void addDefaultLookups(final Collection<? extends Lookup> lookups) {
         if (lookups != null) {
@@ -344,8 +484,8 @@ public class ConfigurationInterpolator {
 
     /**
      * Obtains the lookup object for the specified prefix. This method is called by the {@code lookup()} method. This
-     * implementation will check whether a lookup object is registered for the given prefix. If not, a <b>null</b> lookup
-     * object will be returned (never <b>null</b>).
+     * implementation will check whether a lookup object is registered for the given prefix. If not, a <strong>null</strong> lookup
+     * object will be returned (never <strong>null</strong>).
      *
      * @param prefix the prefix
      * @return the lookup object to be used for this prefix
@@ -378,12 +518,19 @@ public class ConfigurationInterpolator {
     /**
      * Gets the parent {@code ConfigurationInterpolator}.
      *
-     * @return the parent {@code ConfigurationInterpolator} (can be <b>null</b>)
+     * @return the parent {@code ConfigurationInterpolator} (can be <strong>null</strong>)
      */
     public ConfigurationInterpolator getParentInterpolator() {
         return this.parentInterpolator;
     }
 
+    /** Gets the function used to convert interpolated values to strings.
+     * @return function used to convert interpolated values to strings
+     */
+    public Function<Object, String> getStringConverter() {
+        return stringConverter;
+    }
+
     /**
      * Creates and initializes a {@code StringSubstitutor} object which is used for variable substitution. This
      * {@code StringSubstitutor} is assigned a specialized lookup object implementing the correct variable resolving
@@ -452,27 +599,9 @@ public class ConfigurationInterpolator {
         return substitutor.isEnableSubstitutionInVariables();
     }
 
-    /** Gets the function used to convert interpolated values to strings.
-     * @return function used to convert interpolated values to strings
-     */
-    public Function<Object, String> getStringConverter() {
-        return stringConverter;
-    }
-
-    /** Sets the function used to convert interpolated values to strings. Pass
-     * {@code null} to use the default conversion function.
-     * @param stringConverter function used to convert interpolated values to strings
-     *      or {@code null} to use the default conversion function
-     */
-    public void setStringConverter(final Function<Object, String> stringConverter) {
-        this.stringConverter = stringConverter != null
-                ? stringConverter
-                : DefaultStringConverter.INSTANCE;
-    }
-
     /**
-     * Checks whether a value to be interpolated consists of single, simple variable reference, e.g.,
-     * <code>${myvar}</code>. In this case, the variable is resolved directly without using the
+     * Checks whether a value to be interpolated consists of single, simple variable reference, for example,
+     * {@code ${myvar}}. In this case, the variable is resolved directly without using the
      * {@code StringSubstitutor}.
      *
      * @param strValue the value to be interpolated
@@ -497,9 +626,9 @@ public class ConfigurationInterpolator {
      * Registers the given {@code Lookup} object for the specified prefix at this instance. From now on this lookup object
      * will be used for variables that have the specified prefix.
      *
-     * @param prefix the variable prefix (must not be <b>null</b>)
-     * @param lookup the {@code Lookup} object to be used for this prefix (must not be <b>null</b>)
-     * @throws IllegalArgumentException if either the prefix or the {@code Lookup} object is <b>null</b>
+     * @param prefix the variable prefix (must not be <strong>null</strong>)
+     * @param lookup the {@code Lookup} object to be used for this prefix (must not be <strong>null</strong>)
+     * @throws IllegalArgumentException if either the prefix or the {@code Lookup} object is <strong>null</strong>
      */
     public void registerLookup(final String prefix, final Lookup lookup) {
         if (prefix == null) {
@@ -513,11 +642,11 @@ public class ConfigurationInterpolator {
 
     /**
      * Registers all {@code Lookup} objects in the given map with their prefixes at this {@code ConfigurationInterpolator}.
-     * Using this method multiple {@code Lookup} objects can be registered at once. If the passed in map is <b>null</b>,
+     * Using this method multiple {@code Lookup} objects can be registered at once. If the passed in map is <strong>null</strong>,
      * this method does not have any effect.
      *
-     * @param lookups the map with lookups to register (may be <b>null</b>)
-     * @throws IllegalArgumentException if the map contains <b>entries</b>
+     * @param lookups the map with lookups to register (may be <strong>null</strong>)
+     * @throws IllegalArgumentException if the map contains <strong>entries</strong>
      */
     public void registerLookups(final Map<String, ? extends Lookup> lookups) {
         if (lookups != null) {
@@ -543,7 +672,7 @@ public class ConfigurationInterpolator {
      * {@code ConfigurationInterpolator} is available, this object is asked to resolve the variable.
      *
      * @param var the name of the variable whose value is to be looked up which may contain a prefix.
-     * @return the value of this variable or <b>null</b> if it cannot be resolved
+     * @return the value of this variable or <strong>null</strong> if it cannot be resolved
      */
     public Object resolve(final String var) {
         if (var == null) {
@@ -578,7 +707,7 @@ public class ConfigurationInterpolator {
      * Interpolates a string value that consists of a single variable.
      *
      * @param strValue the string to be interpolated
-     * @return the resolved value or <b>null</b> if resolving failed
+     * @return the resolved value or <strong>null</strong> if resolving failed
      */
     private Object resolveSingleVariable(final String strValue) {
         return resolve(extractVariableName(strValue));
@@ -598,150 +727,20 @@ public class ConfigurationInterpolator {
      * Sets the parent {@code ConfigurationInterpolator}. This object is used if the {@code Lookup} objects registered at
      * this object cannot resolve a variable.
      *
-     * @param parentInterpolator the parent {@code ConfigurationInterpolator} object (can be <b>null</b>)
+     * @param parentInterpolator the parent {@code ConfigurationInterpolator} object (can be <strong>null</strong>)
      */
     public void setParentInterpolator(final ConfigurationInterpolator parentInterpolator) {
         this.parentInterpolator = parentInterpolator;
     }
 
-    /**
-     * Internal class used to construct the default {@link Lookup} map used by
-     * {@link ConfigurationInterpolator#getDefaultPrefixLookups()}.
+    /** Sets the function used to convert interpolated values to strings. Pass
+     * {@code null} to use the default conversion function.
+     * @param stringConverter function used to convert interpolated values to strings
+     *      or {@code null} to use the default conversion function
      */
-    static final class DefaultPrefixLookupsHolder {
-
-        /** Singleton instance, initialized with the system properties. */
-        static final DefaultPrefixLookupsHolder INSTANCE = new DefaultPrefixLookupsHolder(System.getProperties());
-
-        /** Default lookup map. */
-        private final Map<String, Lookup> defaultLookups;
-
-        /**
-         * Constructs a new instance initialized with the given properties.
-         * @param props initialization properties
-         */
-        DefaultPrefixLookupsHolder(final Properties props) {
-            final Map<String, Lookup> lookups =
-                    props.containsKey(ConfigurationInterpolator.DEFAULT_PREFIX_LOOKUPS_PROPERTY)
-                        ? parseLookups(props.getProperty(ConfigurationInterpolator.DEFAULT_PREFIX_LOOKUPS_PROPERTY))
-                        : createDefaultLookups();
-
-            defaultLookups = Collections.unmodifiableMap(lookups);
-        }
-
-        /**
-         * Gets the default prefix lookups map.
-         * @return default prefix lookups map
-         */
-        Map<String, Lookup> getDefaultPrefixLookups() {
-            return defaultLookups;
-        }
-
-        /**
-         * Create the lookup map used when the user has requested no customization.
-         * @return default lookup map
-         */
-        private static Map<String, Lookup> createDefaultLookups() {
-            final Map<String, Lookup> lookupMap = new HashMap<>();
-
-            addLookup(DefaultLookups.BASE64_DECODER, lookupMap);
-            addLookup(DefaultLookups.BASE64_ENCODER, lookupMap);
-            addLookup(DefaultLookups.CONST, lookupMap);
-            addLookup(DefaultLookups.DATE, lookupMap);
-            addLookup(DefaultLookups.ENVIRONMENT, lookupMap);
-            addLookup(DefaultLookups.FILE, lookupMap);
-            addLookup(DefaultLookups.JAVA, lookupMap);
-            addLookup(DefaultLookups.LOCAL_HOST, lookupMap);
-            addLookup(DefaultLookups.PROPERTIES, lookupMap);
-            addLookup(DefaultLookups.RESOURCE_BUNDLE, lookupMap);
-            addLookup(DefaultLookups.SYSTEM_PROPERTIES, lookupMap);
-            addLookup(DefaultLookups.URL_DECODER, lookupMap);
-            addLookup(DefaultLookups.URL_ENCODER, lookupMap);
-            addLookup(DefaultLookups.XML, lookupMap);
-
-            return lookupMap;
-        }
-
-        /**
-         * Constructs a lookup map by parsing the given string. The string is expected to contain
-         * comma or space-separated names of values from the {@link DefaultLookups} enum.
-         * @param str string to parse; not null
-         * @return lookup map parsed from the given string
-         * @throws IllegalArgumentException if the string does not contain a valid default lookup
-         *      definition
-         */
-        private static Map<String, Lookup> parseLookups(final String str) {
-            final Map<String, Lookup> lookupMap = new HashMap<>();
-
-            try {
-                for (final String lookupName : str.split("[\\s,]+")) {
-                    if (!lookupName.isEmpty()) {
-                        addLookup(DefaultLookups.valueOf(lookupName.toUpperCase()), lookupMap);
-                    }
-                }
-            } catch (final IllegalArgumentException exc) {
-                throw new IllegalArgumentException("Invalid default lookups definition: " + str, exc);
-            }
-
-            return lookupMap;
-        }
-
-        /**
-         * Add the prefix and lookup from {@code lookup} to {@code map}.
-         * @param lookup lookup to add
-         * @param map map to add to
-         */
-        private static void addLookup(final DefaultLookups lookup, final Map<String, Lookup> map) {
-            map.put(lookup.getPrefix(), lookup.getLookup());
-        }
-    }
-
-    /** Class encapsulating the default logic to convert resolved variable values into strings.
-     * This class is thread-safe.
-     */
-    private static final class DefaultStringConverter implements Function<Object, String> {
-
-        /** Shared instance. */
-        static final DefaultStringConverter INSTANCE = new DefaultStringConverter();
-
-        /** {@inheritDoc} */
-        @Override
-        public String apply(final Object obj) {
-            return Objects.toString(extractSimpleValue(obj), null);
-        }
-
-        /** Attempt to extract a simple value from {@code obj} for use in string conversion.
-         * If the input represents a collection of some sort (e.g., an iterable or array),
-         * the first item from the collection is returned.
-         * @param obj input object
-         * @return extracted simple object
-         */
-        private Object extractSimpleValue(final Object obj) {
-            if (!(obj instanceof String)) {
-                if (obj instanceof Iterable) {
-                   return nextOrNull(((Iterable<?>) obj).iterator());
-                }
-                if (obj instanceof Iterator) {
-                    return nextOrNull((Iterator<?>) obj);
-                }
-                if (obj.getClass().isArray()) {
-                    return Array.getLength(obj) > 0
-                            ? Array.get(obj, 0)
-                            : null;
-                }
-            }
-            return obj;
-        }
-
-        /** Return the next value from {@code it} or {@code null} if no values remain.
-         * @param <T> iterated type
-         * @param it iterator
-         * @return next value from {@code it} or {@code null} if no values remain
-         */
-        private <T> T nextOrNull(final Iterator<T> it) {
-            return it.hasNext()
-                    ? it.next()
-                    : null;
-        }
+    public void setStringConverter(final Function<Object, String> stringConverter) {
+        this.stringConverter = stringConverter != null
+                ? stringConverter
+                : DefaultStringConverter.INSTANCE;
     }
 }
